@@ -109,7 +109,8 @@ static struct cpu_descr const cpu_descrs[MAX_CPU_TYPE] = {
 	{ "ARM Cortex-A7", "arm/armv7-ca7", CPU_ARM_V7_CA7, 5 },
 	{ "ARM Cortex-A15", "arm/armv7-ca15", CPU_ARM_V7_CA15, 7 },
 	{ "Intel Haswell microarchitecture", "i386/haswell", CPU_HASWELL, 4 },
-	{ "IBM zEnterprise EC12", "s390/zEC12", CPU_S390_ZEC12, 1 },	{ "AMD64 generic", "x86-64/generic", CPU_AMD64_GENERIC, 4 },
+	{ "IBM zEnterprise EC12", "s390/zEC12", CPU_S390_ZEC12, 1 },
+	{ "AMD64 generic", "x86-64/generic", CPU_AMD64_GENERIC, 4 },
 	{ "IBM Power Architected Events V1", "ppc64/architected_events_v1", CPU_PPC64_ARCH_V1, 6 },
 	{ "ppc64 POWER8", "ppc64/power8", CPU_PPC64_POWER8, 6 },
 	{ "e500mc", "ppc/e500mc", CPU_PPC_E500MC, 4 },
@@ -120,6 +121,7 @@ static struct cpu_descr const cpu_descrs[MAX_CPU_TYPE] = {
 	{ "Intel Broadwell microarchitecture", "i386/broadwell", CPU_BROADWELL, 4 },
 	{ "ARM Cortex-A57", "arm/armv8-ca57", CPU_ARM_V8_CA57, 6},
 	{ "ARM Cortex-A53", "arm/armv8-ca53", CPU_ARM_V8_CA53, 6},
+	{ "Intel Skylake microarchitecture", "i386/skylake", CPU_SKYLAKE, 4 },
 };
  
 static size_t const nr_cpu_descrs = sizeof(cpu_descrs) / sizeof(struct cpu_descr);
@@ -414,6 +416,11 @@ static op_cpu _get_arm_cpu_type(void)
 		case 0xd03:
 			return op_get_cpu_number("arm/armv8-ca53");
 		}
+	} else if (vendorid == 0x42) {  /* Broadcom Corporation */
+		switch (cpuid) {
+		case 0x00f:
+			return op_get_cpu_number("arm/armv7-ca15");
+		}
 	} else if (vendorid == 0x50) {	/* Applied Micro Circuits Corporation */
 		switch (cpuid) {
 		case 0x000:
@@ -538,10 +545,13 @@ static op_cpu _get_amd_cpu_type(void)
 	family = cpu_family(eax);
 
 	/* These family does not exist in the past.*/
-	if (family < 0x0f || family == 0x13)
+	if ((family < 0x0f && family != 0x6) || family == 0x13)
 		return ret;
 
 	switch (family) {
+	case 0x6:
+		ret = op_get_cpu_number("i386/athlon");
+		break;
 	case 0x0f:
 		ret = op_get_cpu_number("x86-64/hammer");
 		break;
@@ -728,6 +738,7 @@ op_cpu op_cpu_base_type(op_cpu cpu_type)
 	case CPU_NEHALEM:
 	case CPU_HASWELL:
 	case CPU_BROADWELL:
+	case CPU_SKYLAKE:
 	case CPU_SILVERMONT:
 	case CPU_WESTMERE:
 	case CPU_SANDYBRIDGE:
