@@ -238,6 +238,9 @@ static void parse_um_entry(struct op_described_um * entry, char const * line)
 	if (strisprefix(c, "extra:")) {
 		c += 6;
 		entry->extra = parse_extra(c);
+		/* include the regular umask if there are real extra bits */
+		if (entry->extra != EXTRA_NONE)
+			entry->extra |= (entry->value & UMASK_MASK) << UMASK_SHIFT;
 		/* named mask */
 		c = skip_nonws(c);
 		c = skip_ws(c);
@@ -498,6 +501,7 @@ static void read_events(char const * file)
 	int seen_event, seen_counters, seen_um, seen_minimum, seen_name, seen_ext;
 	FILE * fp = fopen(file, "r");
 	int tags;
+	int fail = 0;
 
 	if (!fp) {
 		fprintf(stderr, "oprofile: could not open event description file %s\n", file);
@@ -510,6 +514,8 @@ static void read_events(char const * file)
 	line = op_get_line(fp);
 
 	while (line) {
+		int bad_val = 0;
+		u64 tmp_val = 0ULL;
 		if (empty_line(line) || comment_line(line))
 			goto next;
 
@@ -535,11 +541,21 @@ static void read_events(char const * file)
 				if (strchr(value, '.') != NULL)
 					parse_error("invalid event name");
 				event->name = value;
+				if (bad_val) {
+					fprintf(stderr, "Event %s event code (0x%llx) is too big to fit in an int\n",
+					        event->name, tmp_val);
+					fail = 1;
+					bad_val = 0;
+				}
 			} else if (strcmp(name, "event") == 0) {
 				if (seen_event)
 					parse_error("duplicate event: tag");
 				seen_event = 1;
-				event->val = parse_hex(value);
+				tmp_val = parse_long_hex(value);
+				if (tmp_val > 0xffffffff)
+					bad_val = 1;
+				else
+					event->val = (u32)tmp_val;
 				free(value);
 			} else if (strcmp(name, "counters") == 0) {
 				if (seen_counters)
@@ -599,6 +615,8 @@ next:
 	}
 
 	fclose(fp);
+	if (fail)
+		exit(EXIT_FAILURE);
 }
 
 
@@ -1081,12 +1099,21 @@ static int _is_um_valid_bitmask(struct op_event * event, u32 passed_um)
 	return retval;
 }
 
-int op_check_events(int ctr, u32 nr, u32 um, op_cpu cpu_type)
+static int _is_ppc64_cpu_type(op_cpu cpu_type) {
+	char const * cpu_name = op_get_cpu_name(cpu_type);
+	if (strncmp(cpu_name, "ppc64/power", strlen("ppc64/power")) == 0)
+		return 1;
+	else
+		return 0;
+}
+
+int op_check_events(char * evt_name, int ctr, u32 nr, u32 um, op_cpu cpu_type)
 {
 	int ret = OP_INVALID_EVENT;
 	size_t i;
 	u32 ctr_mask = 1 << ctr;
 	struct list_head * pos;
+	int ibm_power_proc = _is_ppc64_cpu_type(cpu_type);
 
 	load_events(cpu_type);
 
@@ -1095,6 +1122,11 @@ int op_check_events(int ctr, u32 nr, u32 um, op_cpu cpu_type)
 		if (event->val != nr)
 			continue;
 
+		// Why do we have to do this, since event codes are supposed to be unique?
+		// See the big comment below.
+		if (ibm_power_proc && strcmp(evt_name, event->name))
+			continue;
+
 		ret = OP_OK_EVENT;
 
 		if ((event->counter_mask & ctr_mask) == 0)
@@ -1108,7 +1140,28 @@ int op_check_events(int ctr, u32 nr, u32 um, op_cpu cpu_type)
 				if (event->unit->um[i].value == um)
 					break;
 			}
-			if (i == event->unit->num)
+			/* A small number of events on the IBM Power8 processor have real event
+			 * codes that are larger than sizeof(int). Rather than change the width of
+			 * the event code everywhere to be a long int (which would include having to
+			 * change the sample file format), we have defined some internal-use-only
+			 * unit masks for those events. In oprofile's power8 events file, we have
+			 * truncated those event codes to integer size, and the truncated bits are
+			 * used as a unit mask value which is ORed into the event code by
+			 * libpe_utils/op_pe_utils.cpp:_get_event_code(). This technique allowed
+			 * us to handle this situation with minimal code perturbation.  The one
+			 * downside is that the truncated event codes are not unique.  So in this
+			 * function, where we're searching for events by 'nr' (i.e., the event code),
+			 * we have to also make sure the name matches.
+			 *
+			 * If the user gives us an event specification such as:
+			 *      PM_L1MISS_LAT_EXC_256:0x0:1:1
+			 * the above code will actually find a non-zero unit mask for this event and
+			 * we'd normally fail at this point since the user passed '0x0' for a unit mask.
+			 * But we don't expose these internal-use-only UMs to the user, so there's
+			 * no way for them to know about it or to try to use it in their event spec;
+			 * thus, we handle it below.
+			 */
+			if ((i == event->unit->num) && !((um == 0) && ibm_power_proc))
 				ret |= OP_INVALID_UM;
 		}
 
@@ -1159,6 +1212,10 @@ void op_default_event(op_cpu cpu_type, struct op_default_event_descr * descr)
 			descr->name = "CPU_CLK_UNHALTED";
 			break;
 
+		case CPU_SKYLAKE:
+			descr->name = "cpu_clk_unhalted";
+			break;
+
 		case CPU_P4:
 		case CPU_P4_HT2:
 			descr->name = "GLOBAL_POWER_EVENTS";
