@@ -31,8 +31,8 @@ using namespace OP_perf_utils;
 
 operf_process_info::operf_process_info(pid_t tgid, const char * appname,
                                        bool app_arg_is_fullname, bool is_valid)
-: pid(tgid), valid(is_valid), appname_valid(false), forked(false), look_for_appname_match(false),
-  appname_is_fullname(NOT_FULLNAME), num_app_chars_matched(-1)
+: pid(tgid), valid(is_valid), appname_valid(false), look_for_appname_match(false),
+  forked(false), appname_is_fullname(NOT_FULLNAME), num_app_chars_matched(-1)
 {
 	_appname = "";
 	set_appname(appname, app_arg_is_fullname);
@@ -103,7 +103,7 @@ void operf_process_info::set_appname(const char * appname, bool app_arg_is_fulln
 			ostringstream message;
 			message << "PID: " << hex << pid << " Unable to obtain appname from " << exe_symlink << endl
 			        <<  "\t" << strerror(errno) << endl;
-			cerr << message.str();
+			cout << message.str();
 		}
 		if (appname && strcmp(appname, "taskset")) {
 			_appname = appname;
@@ -186,7 +186,7 @@ void operf_process_info::check_mapping_for_appname(struct operf_mmap * mapping)
 		string basename;
 		int num_matched_chars = get_num_matching_chars(mapping->filename, basename);
 		if (num_matched_chars > num_app_chars_matched) {
-			if (num_matched_chars == app_basename.length()) {
+			if (num_matched_chars == (int)app_basename.length()) {
 				appname_is_fullname = YES_FULLNAME;
 				look_for_appname_match = false;
 				appname_valid = true;
@@ -217,11 +217,12 @@ void operf_process_info::find_best_match_appname_all_mappings(void)
 
 }
 
-const struct operf_mmap * operf_process_info::find_mapping_for_sample(u64 sample_addr)
+const struct operf_mmap * operf_process_info::find_mapping_for_sample(u64 sample_addr, bool hypervisor_sample)
 {
 	map<u64, struct operf_mmap *>::iterator it = mmappings.begin();
 	while (it != mmappings.end()) {
-		if (sample_addr >= it->second->start_addr && sample_addr <= it->second->end_addr)
+		if (sample_addr >= it->second->start_addr && sample_addr <= it->second->end_addr &&
+				it->second->is_hypervisor == hypervisor_sample)
 			return it->second;
 		it++;
 	}
