@@ -33,6 +33,7 @@
 #include <sys/wait.h>
 #include <ftw.h>
 #include <getopt.h>
+#include <time.h>
 #include <iostream>
 #include "operf_utils.h"
 #include "op_pe_utils.h"
@@ -1258,6 +1259,7 @@ static int _process_operf_and_app_args(int argc, char * const argv[])
 {
 	bool keep_trying = true;
 	int idx_of_non_options = 0;
+	char * prev_env = getenv("POSIXLY_CORRECT");
 	setenv("POSIXLY_CORRECT", "1", 0);
 	while (keep_trying) {
 		int option_idx = 0;
@@ -1331,6 +1333,10 @@ static int _process_operf_and_app_args(int argc, char * const argv[])
 			__print_usage_and_exit("unexpected end of arg parsing");
 		}
 	}
+
+	if (prev_env == NULL)
+		unsetenv("POSIXLY_CORRECT");
+
 	return idx_of_non_options;
 }
 
